@@ -30,7 +30,8 @@ class Move:
     @classmethod
     def __setup__(cls):
         super(Move, cls).__setup__()
-        cls._allow_modify_closed_period.add('anglo_saxon_quantity')
+        cls._allow_modify_closed_period.update(['in_anglo_saxon_quantity',
+                'out_anglo_saxon_quantity'])
         cls._sql_constraints += [
             ('check_in_anglo_saxon_quantity',
                 'CHECK(quantity >= in_anglo_saxon_quantity)',
@@ -130,7 +131,7 @@ class Move:
             if consumed_qty >= quantity:
                 break
 
-            if type_.startswith('in_'):
+            if type_ == 'in_supplier':
                 with Transaction().set_context(date=move.effective_date):
                     unit_price = Currency.compute(move.currency,
                         move.unit_price, move.company.currency, round=False)
@@ -140,6 +141,7 @@ class Move:
                 cost_price = move.cost_price
 
             yield (move, qty, cost_price)
+            consumed_qty += qty
 
     @classmethod
     def update_anglo_saxon_quantity_product_cost(cls, product, moves,
